.. :changelog:

History
-------

0.1.3 (2015-12-01)
------------------

* add support for keywords with namespaces in edn

0.1.2 (2015-26-11)
------------------

* fix edn encoding from transit on http response

0.1.1 (2015-25-11)
------------------

* add support for http requests
* fix keyword serialization in edn

0.1.0 (2015-25-11)
------------------

* First release on PyPI.
